@@ -8,18 +8,18 @@
 
 #include "../src/etmcalendar.h"
 #include "../src/utils_p.h"
-#include <itemcreatejob.h>
-#include <itemdeletejob.h>
-#include <qtest_akonadi.h>
+#include <KCheckableProxyModel>
+#include <KEMailSettings>
 #include <collectionfetchjob.h>
 #include <collectionfetchscope.h>
 #include <collectionmodifyjob.h>
+#include <itemcreatejob.h>
+#include <itemdeletejob.h>
 #include <itemmodifyjob.h>
-#include <KCheckableProxyModel>
-#include <KEMailSettings>
+#include <qtest_akonadi.h>
 
-#include <QTestEventLoop>
 #include <QSignalSpy>
+#include <QTestEventLoop>
 
 using namespace Akonadi;
 using namespace KCalendarCore;
@@ -46,7 +46,7 @@ void ETMCalendarTest::createIncidence(const QString &uid)
     incidence->setDtStart(QDateTime::currentDateTimeUtc());
     incidence->setSummary(QStringLiteral("summary"));
     item.setPayload<KCalendarCore::Incidence::Ptr>(incidence);
-    auto *job = new ItemCreateJob(item, mCollection, this);
+    auto job = new ItemCreateJob(item, mCollection, this);
     AKVERIFYEXEC(job);
 }
 
@@ -62,7 +62,7 @@ void ETMCalendarTest::createTodo(const QString &uid, const QString &parentUid)
     todo->setSummary(QStringLiteral("summary"));
 
     item.setPayload<KCalendarCore::Incidence::Ptr>(todo);
-    auto *job = new ItemCreateJob(item, mCollection, this);
+    auto job = new ItemCreateJob(item, mCollection, this);
     mIncidencesToAdd++;
     mIncidencesToChange++;
     AKVERIFYEXEC(job);
@@ -70,16 +70,14 @@ void ETMCalendarTest::createTodo(const QString &uid, const QString &parentUid)
 
 void ETMCalendarTest::deleteIncidence(const QString &uid)
 {
-    ItemDeleteJob *job = new ItemDeleteJob(mCalendar->item(uid));
+    auto job = new ItemDeleteJob(mCalendar->item(uid));
     mIncidencesToDelete++;
     AKVERIFYEXEC(job);
 }
 
 void ETMCalendarTest::fetchCollection()
 {
-    CollectionFetchJob *job = new CollectionFetchJob(Collection::root(),
-                                                     CollectionFetchJob::Recursive,
-                                                     this);
+    auto job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive, this);
     // Get list of collections
     job->fetchScope().setContentMimeTypes(QStringList() << QStringLiteral("application/x-vnd.akonadi.calendar.event"));
     AKVERIFYEXEC(job);
@@ -92,20 +90,19 @@ void ETMCalendarTest::fetchCollection()
     QVERIFY(mCollection.isValid());
 }
 
-void ETMCalendarTest:: initTestCase()
+void ETMCalendarTest::initTestCase()
 {
     AkonadiTest::checkTestIsIsolated();
     mIncidencesToAdd = 0;
     mIncidencesToChange = 0;
     mIncidencesToDelete = 0;
 
-    qRegisterMetaType<QSet<QByteArray> >("QSet<QByteArray>");
+    qRegisterMetaType<QSet<QByteArray>>("QSet<QByteArray>");
     fetchCollection();
 
     mCalendar = new ETMCalendar();
     QVERIFY(!mCalendar->isLoaded());
-    connect(mCalendar, &ETMCalendar::collectionsAdded,
-            this, &ETMCalendarTest::handleCollectionsAdded);
+    connect(mCalendar, &ETMCalendar::collectionsAdded, this, &ETMCalendarTest::handleCollectionsAdded);
 
     mCalendar->registerObserver(this);
 
@@ -148,7 +145,7 @@ void ETMCalendarTest::testCollectionChanged_data()
 void ETMCalendarTest::testCollectionChanged()
 {
     QFETCH(Akonadi::Collection, noRightsCollection);
-    auto *job = new CollectionModifyJob(mCollection, this);
+    auto job = new CollectionModifyJob(mCollection, this);
     QSignalSpy spy(mCalendar, &ETMCalendar::collectionChanged);
     mIncidencesToChange = 6;
     AKVERIFYEXEC(job);
@@ -157,7 +154,7 @@ void ETMCalendarTest::testCollectionChanged()
     QCOMPARE(spy.count(), 1);
     QCOMPARE(spy.at(0).count(), 2);
     QCOMPARE(spy.at(0).at(0).value<Akonadi::Collection>(), mCollection);
-    QVERIFY(spy.at(0).at(1).value<QSet<QByteArray> >().contains(QByteArray("AccessRights")));
+    QVERIFY(spy.at(0).at(1).value<QSet<QByteArray>>().contains(QByteArray("AccessRights")));
 }
 
 void ETMCalendarTest::testIncidencesAdded()
@@ -174,7 +171,7 @@ void ETMCalendarTest::testIncidencesModified()
     Incidence::Ptr clone = Incidence::Ptr(CalendarUtils::incidence(item)->clone());
     clone->setSummary(tr("foo33"));
     item.setPayload(clone);
-    auto *job = new ItemModifyJob(item);
+    auto job = new ItemModifyJob(item);
     mIncidencesToChange = 1;
     AKVERIFYEXEC(job);
     QTestEventLoop::instance().enterLoop(10);
@@ -190,7 +187,7 @@ void ETMCalendarTest::testIncidencesDeleted()
     const Item item = mCalendar->item(tr("a"));
     QVERIFY(item.isValid());
     QVERIFY(item.hasPayload());
-    auto *job = new ItemDeleteJob(item);
+    auto job = new ItemDeleteJob(item);
     AKVERIFYEXEC(job);
     mIncidencesToDelete = 1;
     QTestEventLoop::instance().enterLoop(10);
@@ -224,7 +221,7 @@ void ETMCalendarTest::testUnselectCollection()
     checkable->setData(firstIndex, Qt::Unchecked, Qt::CheckStateRole);
 
     if (mIncidencesToDelete > 0) { // Actually they probably where deleted already
-        //doesn't need the event loop, but just in case
+        // doesn't need the event loop, but just in case
         QTestEventLoop::instance().enterLoop(10);
 
         if (QTestEventLoop::instance().timeout()) {
@@ -293,7 +290,7 @@ void ETMCalendarTest::calendarIncidenceChanged(const Incidence::Ptr &incidence)
 
 void ETMCalendarTest::calendarIncidenceDeleted(const Incidence::Ptr &incidence, const KCalendarCore::Calendar *cal)
 {
-    Q_UNUSED(cal);
+    Q_UNUSED(cal)
     const QString id = incidence->customProperty("VOLATILE", "AKONADI-ID");
     QVERIFY(!id.isEmpty());
     QVERIFY(mIncidencesToDelete > 0);
@@ -353,7 +350,7 @@ void ETMCalendarTest::testSubTodos()
     ta->setRelatedTo(tr("tb"));
     mIncidencesToChange++;
 
-    auto *job = new ItemModifyJob(ta_item);
+    auto job = new ItemModifyJob(ta_item);
     AKVERIFYEXEC(job);
     waitForIt();
 
@@ -400,7 +397,7 @@ void ETMCalendarTest::testSubTodos()
     // Delete everything, so we don't have duplicate ids when the next test row runs
     Akonadi::Item::List itemsToDelete = mCalendar->items();
     mIncidencesToDelete = itemsToDelete.count();
-    auto *deleteJob = new ItemDeleteJob(itemsToDelete);
+    auto deleteJob = new ItemDeleteJob(itemsToDelete);
     AKVERIFYEXEC(deleteJob);
     waitForIt();
 }
@@ -424,7 +421,7 @@ void ETMCalendarTest::testNotifyObserverBug()
     mIncidencesToChange = 1;
     incidence->setSummary(QStringLiteral("new-summary"));
     item.setPayload(incidence);
-    auto *job = new ItemModifyJob(item);
+    auto job = new ItemModifyJob(item);
     AKVERIFYEXEC(job);
 
     // The test will now happen inside ETMCalendarTest::calendarIncidenceChanged()
@@ -446,7 +443,7 @@ void ETMCalendarTest::testUidChange()
     QVERIFY(item.isValid());
     item.setPayload(clone);
     mIncidencesToChange = 1;
-    auto *job = new ItemModifyJob(item);
+    auto job = new ItemModifyJob(item);
     AKVERIFYEXEC(job);
 
     waitForIt();
@@ -501,7 +498,7 @@ void ETMCalendarTest::testShareETM()
     createTodo(QStringLiteral("uid-123"), QString());
     waitForIt();
 
-    auto *calendar2 = new ETMCalendar(mCalendar, this);
+    auto calendar2 = new ETMCalendar(mCalendar, this);
     calendar2->registerObserver(this);
 
     // Uncheck our calendar
@@ -535,7 +532,7 @@ void ETMCalendarTest::testFilterInvitations()
     incidence->addAttendee(me);
 
     item.setPayload<KCalendarCore::Incidence::Ptr>(incidence);
-    auto *job = new ItemCreateJob(item, mCollection, this);
+    auto job = new ItemCreateJob(item, mCollection, this);
     AKVERIFYEXEC(job);
     waitForIt();
     // incidence do not pop up in model
@@ -555,7 +552,7 @@ void ETMCalendarTest::testFilterInvitationsChanged()
     mIncidencesToAdd = 1;
     createIncidence(uid);
     waitForIt();
-    QCOMPARE(mCalendar->model()->rowCount(), anz+1);
+    QCOMPARE(mCalendar->model()->rowCount(), anz + 1);
 
     Incidence::Ptr incidence = mCalendar->incidence(uid);
     Item item = mCalendar->item(uid);
@@ -565,7 +562,7 @@ void ETMCalendarTest::testFilterInvitationsChanged()
     item.setPayload<KCalendarCore::Incidence::Ptr>(incidence);
 
     mIncidencesToDelete = 1;
-    auto *modifyJob = new ItemModifyJob(item, this);
+    auto modifyJob = new ItemModifyJob(item, this);
     AKVERIFYEXEC(modifyJob);
     waitForIt();
     QCOMPARE(mCalendar->model()->rowCount(), anz);
@@ -582,7 +579,7 @@ void ETMCalendarTest::testFilterInvitationsChanged()
     modifyJob = new ItemModifyJob(item, this);
     AKVERIFYEXEC(modifyJob);
     waitForIt();
-    QCOMPARE(mCalendar->model()->rowCount(), anz+1);
+    QCOMPARE(mCalendar->model()->rowCount(), anz + 1);
 }
 
 void ETMCalendarTest::waitForIt()
@@ -593,7 +590,7 @@ void ETMCalendarTest::waitForIt()
 
 void ETMCalendarTest::checkExitLoop()
 {
-    //qDebug() << "checkExitLoop: current state: " << mIncidencesToDelete << mIncidencesToAdd << mIncidencesToChange;
+    // qDebug() << "checkExitLoop: current state: " << mIncidencesToDelete << mIncidencesToAdd << mIncidencesToChange;
     if (mIncidencesToDelete == 0 && mIncidencesToAdd == 0 && mIncidencesToChange == 0) {
         QTestEventLoop::instance().exitLoop();
     }
