@@ -19,21 +19,18 @@
 using namespace Akonadi;
 using namespace KCalendarCore;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class History;
 
-enum OperationType {
-    TypeNone,
-    TypeUndo,
-    TypeRedo
-};
+enum OperationType { TypeNone, TypeUndo, TypeRedo };
 
 class Entry : public QObject
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<Entry> Ptr;
-    typedef QVector<Entry::Ptr> List;
+    using Ptr = QSharedPointer<Entry>;
+    using List = QVector<Entry::Ptr>;
     Entry(const Akonadi::Item &item, const QString &description, History *qq);
     Entry(const Akonadi::Item::List &items, const QString &description, History *qq);
     virtual void updateIds(Item::Id oldId, Item::Id newId);
@@ -43,6 +40,7 @@ public:
     QString mDescription;
 Q_SIGNALS:
     void finished(Akonadi::IncidenceChanger::ResultCode, const QString &errorString);
+
 protected:
     virtual bool undo() = 0;
     virtual bool redo() = 0;
@@ -52,12 +50,13 @@ protected:
     QHash<Akonadi::Item::Id, int> mLatestRevisionByItemId;
     History *q = nullptr;
     QVector<int> mChangeIds;
+
 private:
     void init(const QString &description, History *qq);
     Q_DISABLE_COPY(Entry)
 };
 
-class History::Private : public QObject
+class AKONADI_CALENDAR_EXPORT History::Private : public QObject
 {
     Q_OBJECT
 public:
@@ -69,7 +68,6 @@ public:
     void doIt(OperationType);
     void stackEntry(const Entry::Ptr &entry, uint atomicOperationId);
     void updateIds(Item::Id oldId, Item::Id newId);
-    void finishOperation(int changeId, History::ResultCode, const QString &errorString);
     QStack<Entry::Ptr> &destinationStack();
     QStack<Entry::Ptr> &stack(OperationType);
     QStack<Entry::Ptr> &stack();
@@ -78,8 +76,6 @@ public:
     void emitDone(OperationType, History::ResultCode);
     void setEnabled(bool enabled);
 
-    bool isUndoAvailable() const;
-    bool isRedoAvailable() const;
 
     int redoCount() const;
     int undoCount() const;
@@ -97,9 +93,9 @@ public:
     bool mUndoAllInProgress;
 
     /**
-      * When recordCreation/Deletion/Modification is called and an undo operation is already in progress
-      * the entry is added here.
-      */
+     * When recordCreation/Deletion/Modification is called and an undo operation is already in progress
+     * the entry is added here.
+     */
     QVector<Entry::Ptr> mQueuedEntries;
     bool mEnabled;
     QPointer<QWidget> mCurrentParent;
@@ -115,16 +111,18 @@ class CreationEntry : public Entry
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<CreationEntry> Ptr;
+    using Ptr = QSharedPointer<CreationEntry>;
     CreationEntry(const Akonadi::Item &item, const QString &description, History *q);
 
     bool undo() override;
     bool redo() override;
 
 private Q_SLOTS:
-    void onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &deletedIds, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+    void
+    onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &deletedIds, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
     void onCreateFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+
 private:
     Q_DISABLE_COPY(CreationEntry)
 };
@@ -138,9 +136,11 @@ public:
     bool redo() override;
 
 private Q_SLOTS:
-    void onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &deletedIds, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+    void
+    onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &deletedIds, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
     void onCreateFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+
 private:
     IncidenceChanger::ResultCode mResultCode;
     QString mErrorString;
@@ -160,6 +160,7 @@ public:
 
 private Q_SLOTS:
     void onModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+
 private:
     Q_DISABLE_COPY(ModificationEntry)
     Incidence::Ptr mOriginalPayload;
@@ -169,7 +170,7 @@ class MultiEntry : public Entry
 {
     Q_OBJECT
 public:
-    typedef QSharedPointer<MultiEntry> Ptr;
+    using Ptr = QSharedPointer<MultiEntry>;
     MultiEntry(int id, const QString &description, History *q);
 
     void addEntry(const Entry::Ptr &entry);
@@ -181,8 +182,10 @@ protected:
 
 private Q_SLOTS:
     void onEntryFinished(Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+
 public:
     const uint mAtomicOperationId;
+
 private:
     Entry::List mEntries;
     int mFinishedEntries;
