@@ -10,11 +10,11 @@
 
 #include <entitytreemodel.h>
 
-#include <QAction>
 #include <KActionCollection>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
 #include <KLocalizedString>
+#include <QAction>
 
 #include <QItemSelectionModel>
 
@@ -31,8 +31,7 @@ public:
         , mParent(parent)
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
-        mParent->connect(mGenericManager, &StandardActionManager::actionStateUpdated,
-                         mParent, &StandardCalendarActionManager::actionStateUpdated);
+        mParent->connect(mGenericManager, &StandardActionManager::actionStateUpdated, mParent, &StandardCalendarActionManager::actionStateUpdated);
         mGenericManager->setMimeTypeFilter(QStringList() << QStringLiteral("text/calendar"));
         mGenericManager->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
     }
@@ -46,192 +45,153 @@ public:
     {
         switch (type) {
         case Akonadi::StandardActionManager::CreateCollection:
-            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setText(
-                i18n("Add Folder..."));
-            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setWhatsThis(
-                i18n("Add a new calendar folder to the currently selected calendar folder."));
-            mGenericManager->setContextText(
-                StandardActionManager::CreateCollection, StandardActionManager::DialogTitle,
-                i18nc("@title:window", "New Folder"));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setText(i18n("Add Folder..."));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)
+                ->setWhatsThis(i18n("Add a new calendar folder to the currently selected calendar folder."));
+            mGenericManager->setContextText(StandardActionManager::CreateCollection, StandardActionManager::DialogTitle, i18nc("@title:window", "New Folder"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText,
-                ki18n("Could not create calendar folder: %1"));
+            mGenericManager->setContextText(StandardActionManager::CreateCollection,
+                                            StandardActionManager::ErrorMessageText,
+                                            ki18n("Could not create calendar folder: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageTitle,
-                i18n("Calendar folder creation failed"));
-            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setProperty("ContentMimeTypes", QStringList()
-                                                                                                   <<QStringLiteral("inode/directory")
-                                                                                                   <<QStringLiteral("application/x-vnd.akonadi.calendar.todo")
-                                                                                                   <<QStringLiteral("application/x-vnd.akonadi.calendar.event")
-                                                                                                   <<QStringLiteral("application/x-vnd.akonadi.calendar.journal"));
+            mGenericManager->setContextText(StandardActionManager::CreateCollection,
+                                            StandardActionManager::ErrorMessageTitle,
+                                            i18n("Calendar folder creation failed"));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)
+                ->setProperty("ContentMimeTypes",
+                              QStringList() << QStringLiteral("inode/directory") << QStringLiteral("application/x-vnd.akonadi.calendar.todo")
+                                            << QStringLiteral("application/x-vnd.akonadi.calendar.event")
+                                            << QStringLiteral("application/x-vnd.akonadi.calendar.journal"));
 
             break;
-        case  Akonadi::StandardActionManager::CopyCollections:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyCollections,
-                                           ki18np("Copy Folder", "Copy %1 Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::CopyCollections)->setWhatsThis(
-                i18n("Copy the selected calendar folders to the clipboard."));
+        case Akonadi::StandardActionManager::CopyCollections:
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyCollections, ki18np("Copy Folder", "Copy %1 Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::CopyCollections)
+                ->setWhatsThis(i18n("Copy the selected calendar folders to the clipboard."));
             break;
         case Akonadi::StandardActionManager::DeleteCollections:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteCollections,
-                                           ki18np("Delete Folder", "Delete %1 Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::DeleteCollections)->setWhatsThis(
-                i18n("Delete the selected calendar folders from the calendar."));
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::MessageBoxText,
-                ki18np("Do you really want to delete this calendar folder and all its sub-folders?",
-                       "Do you really want to delete %1 calendar folders and all their sub-folders?"));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteCollections, ki18np("Delete Folder", "Delete %1 Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::DeleteCollections)
+                ->setWhatsThis(i18n("Delete the selected calendar folders from the calendar."));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::MessageBoxText,
+                                            ki18np("Do you really want to delete this calendar folder and all its sub-folders?",
+                                                   "Do you really want to delete %1 calendar folders and all their sub-folders?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::MessageBoxTitle,
-                ki18ncp("@title:window", "Delete calendar folder?", "Delete calendar folders?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::MessageBoxTitle,
+                                            ki18ncp("@title:window", "Delete calendar folder?", "Delete calendar folders?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageText,
-                ki18n("Could not delete calendar folder: %1"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::ErrorMessageText,
+                                            ki18n("Could not delete calendar folder: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageTitle,
-                i18n("Calendar folder deletion failed"));
+            mGenericManager->setContextText(StandardActionManager::DeleteCollections,
+                                            StandardActionManager::ErrorMessageTitle,
+                                            i18n("Calendar folder deletion failed"));
 
             break;
         case Akonadi::StandardActionManager::SynchronizeCollections:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeCollections,
-                                           ki18np("Update Folder", "Update %1 Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollections)->setWhatsThis(
-                i18n("Update the content of the selected calendar folders."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeCollections, ki18np("Update Folder", "Update %1 Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollections)
+                ->setWhatsThis(i18n("Update the content of the selected calendar folders."));
 
             break;
         case Akonadi::StandardActionManager::CutCollections:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CutCollections,
-                                           ki18np("Cut Folder", "Cut %1 Folders"));
-            mGenericManager->action(Akonadi::StandardActionManager::CutCollections)->setWhatsThis(
-                i18n("Cut the selected calendar folders from the calendar."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CutCollections, ki18np("Cut Folder", "Cut %1 Folders"));
+            mGenericManager->action(Akonadi::StandardActionManager::CutCollections)->setWhatsThis(i18n("Cut the selected calendar folders from the calendar."));
             break;
         case Akonadi::StandardActionManager::CollectionProperties:
-            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)->setText(
-                i18n("Folder Properties..."));
-            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)->setWhatsThis(
-                i18n("Open a dialog to edit the properties of the selected calendar folder."));
-            mGenericManager->setContextText(
-                StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,
-                ki18nc("@title:window", "Properties of Calendar Folder %1"));
+            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)->setText(i18n("Folder Properties..."));
+            mGenericManager->action(Akonadi::StandardActionManager::CollectionProperties)
+                ->setWhatsThis(i18n("Open a dialog to edit the properties of the selected calendar folder."));
+            mGenericManager->setContextText(StandardActionManager::CollectionProperties,
+                                            StandardActionManager::DialogTitle,
+                                            ki18nc("@title:window", "Properties of Calendar Folder %1"));
             break;
         case Akonadi::StandardActionManager::CopyItems:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                           ki18np("Copy Event", "Copy %1 Events"));
-            mGenericManager->action(Akonadi::StandardActionManager::CopyItems)->setWhatsThis(
-                i18n("Copy the selected events to the clipboard."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy Event", "Copy %1 Events"));
+            mGenericManager->action(Akonadi::StandardActionManager::CopyItems)->setWhatsThis(i18n("Copy the selected events to the clipboard."));
 
             break;
         case Akonadi::StandardActionManager::DeleteItems:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                           ki18np("Delete Event", "Delete %1 Events"));
-            mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)->setWhatsThis(
-                i18n("Delete the selected events from the calendar."));
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::MessageBoxText,
-                ki18np("Do you really want to delete the selected event?",
-                       "Do you really want to delete %1 events?"));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete Event", "Delete %1 Events"));
+            mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)->setWhatsThis(i18n("Delete the selected events from the calendar."));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems,
+                                            StandardActionManager::MessageBoxText,
+                                            ki18np("Do you really want to delete the selected event?", "Do you really want to delete %1 events?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::MessageBoxTitle,
-                ki18ncp("@title:window", "Delete Event?", "Delete Events?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems,
+                                            StandardActionManager::MessageBoxTitle,
+                                            ki18ncp("@title:window", "Delete Event?", "Delete Events?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText,
-                ki18n("Could not delete event: %1"));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText, ki18n("Could not delete event: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle,
-                i18n("Event deletion failed"));
+            mGenericManager->setContextText(StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle, i18n("Event deletion failed"));
             break;
 
         case Akonadi::StandardActionManager::CutItems:
-            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                           ki18np("Cut Event", "Cut %1 Events"));
-            mGenericManager->action(Akonadi::StandardActionManager::CutItems)->setWhatsThis(
-                i18n("Cut the selected events from the calendar."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut Event", "Cut %1 Events"));
+            mGenericManager->action(Akonadi::StandardActionManager::CutItems)->setWhatsThis(i18n("Cut the selected events from the calendar."));
             break;
         case Akonadi::StandardActionManager::CreateResource:
-            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)->setText(
-                i18n("Add &Calendar..."));
-            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)->setWhatsThis(
-                i18n("Add a new calendar<p>"
-                     "You will be presented with a dialog where you can select "
-                     "the type of the calendar that shall be added.</p>"));
-            mGenericManager->setContextText(
-                StandardActionManager::CreateResource, StandardActionManager::DialogTitle,
-                i18nc("@title:window", "Add Calendar"));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)->setText(i18n("Add &Calendar..."));
+            mGenericManager->action(Akonadi::StandardActionManager::CreateResource)
+                ->setWhatsThis(i18n("Add a new calendar<p>"
+                                    "You will be presented with a dialog where you can select "
+                                    "the type of the calendar that shall be added.</p>"));
+            mGenericManager->setContextText(StandardActionManager::CreateResource, StandardActionManager::DialogTitle, i18nc("@title:window", "Add Calendar"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateResource, StandardActionManager::ErrorMessageText,
-                ki18n("Could not create calendar: %1"));
+            mGenericManager->setContextText(StandardActionManager::CreateResource,
+                                            StandardActionManager::ErrorMessageText,
+                                            ki18n("Could not create calendar: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::CreateResource, StandardActionManager::ErrorMessageTitle,
-                i18n("Calendar creation failed"));
+            mGenericManager->setContextText(StandardActionManager::CreateResource, StandardActionManager::ErrorMessageTitle, i18n("Calendar creation failed"));
 
             break;
         case Akonadi::StandardActionManager::DeleteResources:
 
-            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteResources,
-                                           ki18np("&Delete Calendar", "&Delete %1 Calendars"));
-            mGenericManager->action(Akonadi::StandardActionManager::DeleteResources)->setWhatsThis(
-                i18n("Delete the selected calendars<p>"
-                     "The currently selected calendars will be deleted, "
-                     "along with all the events, todos and journals they contain.</p>"));
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteResources, StandardActionManager::MessageBoxText,
-                ki18np("Do you really want to delete this calendar?",
-                       "Do you really want to delete %1 calendars?"));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteResources, ki18np("&Delete Calendar", "&Delete %1 Calendars"));
+            mGenericManager->action(Akonadi::StandardActionManager::DeleteResources)
+                ->setWhatsThis(i18n("Delete the selected calendars<p>"
+                                    "The currently selected calendars will be deleted, "
+                                    "along with all the events, todos and journals they contain.</p>"));
+            mGenericManager->setContextText(StandardActionManager::DeleteResources,
+                                            StandardActionManager::MessageBoxText,
+                                            ki18np("Do you really want to delete this calendar?", "Do you really want to delete %1 calendars?"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::DeleteResources, StandardActionManager::MessageBoxTitle,
-                ki18ncp("@title:window", "Delete Calendar?", "Delete Calendars?"));
+            mGenericManager->setContextText(StandardActionManager::DeleteResources,
+                                            StandardActionManager::MessageBoxTitle,
+                                            ki18ncp("@title:window", "Delete Calendar?", "Delete Calendars?"));
 
             break;
         case Akonadi::StandardActionManager::ResourceProperties:
-            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)->setText(
-                i18n("Calendar Properties..."));
-            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)->setWhatsThis(
-                i18n("Open a dialog to edit properties of the selected calendar."));
+            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)->setText(i18n("Calendar Properties..."));
+            mGenericManager->action(Akonadi::StandardActionManager::ResourceProperties)
+                ->setWhatsThis(i18n("Open a dialog to edit properties of the selected calendar."));
             break;
         case Akonadi::StandardActionManager::SynchronizeResources:
 
-            mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeResources,
-                                           ki18np("Update Calendar", "Update %1 Calendars"));
-            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeResources)->setWhatsThis(
-                i18n("Updates the content of all folders of the selected calendars."));
+            mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeResources, ki18np("Update Calendar", "Update %1 Calendars"));
+            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeResources)
+                ->setWhatsThis(i18n("Updates the content of all folders of the selected calendars."));
             break;
         case Akonadi::StandardActionManager::CopyItemToMenu:
-            mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu)->setText(
-                i18n("&Copy to Calendar"));
-            mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu)->setWhatsThis(
-                i18n("Copy the selected event to a different calendar."));
+            mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu)->setText(i18n("&Copy to Calendar"));
+            mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu)->setWhatsThis(i18n("Copy the selected event to a different calendar."));
             break;
         case Akonadi::StandardActionManager::MoveItemToMenu:
-            mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu)->setText(
-                i18n("&Move to Calendar"));
-            mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu)->setWhatsThis(
-                i18n("Move the selected event to a different calendar."));
+            mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu)->setText(i18n("&Move to Calendar"));
+            mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu)->setWhatsThis(i18n("Move the selected event to a different calendar."));
             break;
         case StandardActionManager::Paste:
-            mGenericManager->setContextText(
-                StandardActionManager::Paste, StandardActionManager::ErrorMessageText,
-                ki18n("Could not paste event: %1"));
+            mGenericManager->setContextText(StandardActionManager::Paste, StandardActionManager::ErrorMessageText, ki18n("Could not paste event: %1"));
 
-            mGenericManager->setContextText(
-                StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle,
-                i18n("Paste failed"));
+            mGenericManager->setContextText(StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle, i18n("Paste failed"));
             break;
         case Akonadi::StandardActionManager::SynchronizeCollectionTree:
-            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollectionTree)->setText(
-                i18n("Update Available Calendars"));
-            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollectionTree)->setWhatsThis(
-                i18n("Updates the tree of available calendars."));
+            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollectionTree)->setText(i18n("Update Available Calendars"));
+            mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollectionTree)->setWhatsThis(i18n("Updates the tree of available calendars."));
 
             break;
         default:
@@ -283,11 +243,9 @@ public:
 
     static bool hasWritableCollection(const QModelIndex &index, const QString &mimeType)
     {
-        const Akonadi::Collection collection
-            = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         if (collection.isValid()) {
-            if (collection.contentMimeTypes().contains(mimeType)
-                && (collection.rights() & Akonadi::Collection::CanCreateItem)) {
+            if (collection.contentMimeTypes().contains(mimeType) && (collection.rights() & Akonadi::Collection::CanCreateItem)) {
                 return true;
             }
         }
@@ -336,8 +294,7 @@ public:
                 const QString mimeType = index.data(EntityTreeModel::MimeTypeRole).toString();
                 if (mimeType == KCalendarCore::Event::eventMimeType()) {
                     if (mGenericManager->action(Akonadi::StandardActionManager::CopyItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                                       ki18np("Copy Event", "Copy %1 Events"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy Event", "Copy %1 Events"));
                     }
                     QAction *act = mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu);
                     if (act) {
@@ -348,12 +305,10 @@ public:
                         act->setText(i18n("Copy Event To"));
                     }
                     if (mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                                       ki18np("Delete Event", "Delete %1 Events"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete Event", "Delete %1 Events"));
                     }
                     if (mGenericManager->action(Akonadi::StandardActionManager::CutItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                                       ki18np("Cut Event", "Cut %1 Events"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut Event", "Cut %1 Events"));
                     }
                     act = mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu);
                     if (act) {
@@ -369,8 +324,7 @@ public:
                     }
                 } else if (mimeType == KCalendarCore::Todo::todoMimeType()) {
                     if (mGenericManager->action(Akonadi::StandardActionManager::CopyItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                                       ki18np("Copy To-do", "Copy %1 To-dos"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy To-do", "Copy %1 To-dos"));
                     }
                     QAction *act = mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu);
                     if (act) {
@@ -381,12 +335,10 @@ public:
                         act->setText(i18n("Copy To-do To"));
                     }
                     if (mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                                       ki18np("Delete To-do", "Delete %1 To-dos"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete To-do", "Delete %1 To-dos"));
                     }
                     if (mGenericManager->action(Akonadi::StandardActionManager::CutItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                                       ki18np("Cut To-do", "Cut %1 To-dos"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut To-do", "Cut %1 To-dos"));
                     }
                     act = mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu);
                     if (act) {
@@ -402,8 +354,7 @@ public:
                     }
                 } else if (mimeType == KCalendarCore::Journal::journalMimeType()) {
                     if (mGenericManager->action(Akonadi::StandardActionManager::CopyItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems,
-                                                       ki18np("Copy Journal", "Copy %1 Journals"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::CopyItems, ki18np("Copy Journal", "Copy %1 Journals"));
                     }
                     QAction *act = mGenericManager->action(Akonadi::StandardActionManager::CopyItemToMenu);
                     if (act) {
@@ -414,12 +365,10 @@ public:
                         act->setText(i18n("Copy Journal To"));
                     }
                     if (mGenericManager->action(Akonadi::StandardActionManager::DeleteItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems,
-                                                       ki18np("Delete Journal", "Delete %1 Journals"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteItems, ki18np("Delete Journal", "Delete %1 Journals"));
                     }
                     if (mGenericManager->action(Akonadi::StandardActionManager::CutItems)) {
-                        mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems,
-                                                       ki18np("Cut Journal", "Cut %1 Journals"));
+                        mGenericManager->setActionText(Akonadi::StandardActionManager::CutItems, ki18np("Cut Journal", "Cut %1 Journals"));
                     }
                     act = mGenericManager->action(Akonadi::StandardActionManager::MoveItemToMenu);
                     if (act) {
@@ -625,7 +574,7 @@ QAction *StandardCalendarActionManager::createAction(StandardCalendarActionManag
         });
         break;
     default:
-        Q_ASSERT(false);   // should never happen
+        Q_ASSERT(false); // should never happen
         break;
     }
 
